@@ -77,7 +77,6 @@ use App::Dochazka::CLI::Commands::Interval qw(
     interval_new_date_time_date1_time1
     interval_new_time_time1
     interval_new_timerange
-    interval_summary
 );
 use App::Dochazka::CLI::Commands::Misc qw( 
     change_prompt_date 
@@ -650,6 +649,8 @@ our $dispatch_map = {
     "EMPLOYEE_SPEC INTERVAL FILLUP COMMIT" => \&interval_promptdate,
     "INTERVAL SUMMARY" => \&interval_promptdate,
     "EMPLOYEE_SPEC INTERVAL SUMMARY" => \&interval_promptdate,
+    "INTERVAL REPORT" => \&interval_promptdate,
+    "EMPLOYEE_SPEC INTERVAL REPORT" => \&interval_promptdate,
     "INTERVAL DELETE" => \&interval_promptdate,
     "EMPLOYEE_SPEC INTERVAL DELETE" => \&interval_promptdate,
 
@@ -663,6 +664,8 @@ our $dispatch_map = {
     "EMPLOYEE_SPEC INTERVAL FILLUP _DATE COMMIT" => \&interval_date,
     "INTERVAL SUMMARY _DATE" => \&interval_date,
     "EMPLOYEE_SPEC INTERVAL SUMMARY _DATE" => \&interval_date,
+    "INTERVAL REPORT _DATE" => \&interval_date,
+    "EMPLOYEE_SPEC INTERVAL REPORT _DATE" => \&interval_date,
     "INTERVAL DELETE _DATE" => \&interval_date,
     "EMPLOYEE_SPEC INTERVAL DELETE _DATE" => \&interval_date,
 
@@ -676,6 +679,8 @@ our $dispatch_map = {
     "EMPLOYEE_SPEC INTERVAL FILLUP _DATE _DATE1 COMMIT" => \&interval_date_date1,
     "INTERVAL SUMMARY _DATE _DATE1" => \&interval_date_date1,
     "EMPLOYEE_SPEC INTERVAL SUMMARY _DATE _DATE1" => \&interval_date_date1,
+    "INTERVAL REPORT _DATE _DATE1" => \&interval_date_date1,
+    "EMPLOYEE_SPEC INTERVAL REPORT _DATE _DATE1" => \&interval_date_date1,
     "INTERVAL DELETE _DATE _DATE1" => \&interval_date_date1,
     "EMPLOYEE_SPEC INTERVAL DELETE _DATE _DATE1" => \&interval_date_date1,
 
@@ -689,6 +694,8 @@ our $dispatch_map = {
     "EMPLOYEE_SPEC INTERVAL FILLUP _DATE _HYPHEN _DATE1 COMMIT" => \&interval_date_date1,
     "INTERVAL SUMMARY _DATE _HYPHEN _DATE1" => \&interval_date_date1,
     "EMPLOYEE_SPEC INTERVAL SUMMARY _DATE _HYPHEN _DATE1" => \&interval_date_date1,
+    "INTERVAL REPORT _DATE _HYPHEN _DATE1" => \&interval_date_date1,
+    "EMPLOYEE_SPEC INTERVAL REPORT _DATE _HYPHEN _DATE1" => \&interval_date_date1,
     "INTERVAL DELETE _DATE _HYPHEN _DATE1" => \&interval_date_date1,
     "EMPLOYEE_SPEC INTERVAL DELETE _DATE _HYPHEN _DATE1" => \&interval_date_date1,
 
@@ -702,6 +709,8 @@ our $dispatch_map = {
     "EMPLOYEE_SPEC INTERVAL FILLUP _MONTH COMMIT" => \&interval_month,
     "INTERVAL SUMMARY _MONTH" => \&interval_month,
     "EMPLOYEE_SPEC INTERVAL SUMMARY _MONTH" => \&interval_month,
+    "INTERVAL REPORT _MONTH" => \&interval_month,
+    "EMPLOYEE_SPEC INTERVAL REPORT _MONTH" => \&interval_month,
     "INTERVAL DELETE _MONTH" => \&interval_month,
     "EMPLOYEE_SPEC INTERVAL DELETE _MONTH" => \&interval_month,
 
@@ -715,6 +724,8 @@ our $dispatch_map = {
     "EMPLOYEE_SPEC INTERVAL FILLUP _MONTH _NUM COMMIT" => \&interval_month,
     "INTERVAL SUMMARY _MONTH _NUM" => \&interval_month,
     "EMPLOYEE_SPEC INTERVAL SUMMARY _MONTH _NUM" => \&interval_month,
+    "INTERVAL REPORT _MONTH _NUM" => \&interval_month,
+    "EMPLOYEE_SPEC INTERVAL REPORT _MONTH _NUM" => \&interval_month,
     "INTERVAL DELETE _MONTH _NUM" => \&interval_month,
     "EMPLOYEE_SPEC INTERVAL DELETE _MONTH _NUM" => \&interval_month,
 
@@ -728,6 +739,8 @@ our $dispatch_map = {
     "EMPLOYEE_SPEC INTERVAL FILLUP _NUM COMMIT" => \&interval_num_num1,
     "INTERVAL SUMMARY _NUM" => \&interval_num_num1,
     "EMPLOYEE_SPEC INTERVAL SUMMARY _NUM" => \&interval_num_num1,
+    "INTERVAL REPORT _NUM" => \&interval_num_num1,
+    "EMPLOYEE_SPEC INTERVAL REPORT _NUM" => \&interval_num_num1,
     "INTERVAL DELETE _NUM" => \&interval_num_num1,
     "EMPLOYEE_SPEC INTERVAL DELETE _NUM" => \&interval_num_num1,
 
@@ -741,6 +754,8 @@ our $dispatch_map = {
     "EMPLOYEE_SPEC INTERVAL FILLUP _NUM _NUM1 COMMIT" => \&interval_num_num1,
     "INTERVAL SUMMARY _NUM _NUM1" => \&interval_num_num1,
     "EMPLOYEE_SPEC INTERVAL SUMMARY _NUM _NUM1" => \&interval_num_num1,
+    "INTERVAL REPORT _NUM _NUM1" => \&interval_num_num1,
+    "EMPLOYEE_SPEC INTERVAL REPORT _NUM _NUM1" => \&interval_num_num1,
     "INTERVAL DELETE _NUM _NUM1" => \&interval_num_num1,
     "EMPLOYEE_SPEC INTERVAL DELETE _NUM _NUM1" => \&interval_num_num1,
 
@@ -750,6 +765,8 @@ our $dispatch_map = {
     "EMPLOYEE_SPEC INTERVAL FILLUP _TSRANGE COMMIT" => \&interval_fillup_tsrange,
     "INTERVAL SUMMARY _TSRANGE" => \&interval_fillup_tsrange,
     "EMPLOYEE_SPEC INTERVAL SUMMARY _TSRANGE" => \&interval_fillup_tsrange,
+    "INTERVAL REPORT _TSRANGE" => \&interval_fillup_tsrange,
+    "EMPLOYEE_SPEC INTERVAL REPORT _TSRANGE" => \&interval_fillup_tsrange,
 
     # add/insert new intervals
     "INTERVAL _TIME _TIME1 _TERM" => \&interval_new_time_time1,
